Python: module fileobj

fileobj | index /tmp/makerelease-pwman-python.te7lW1kN/pwman-python-2.4/libpwman/fileobj.py

`# Simple object file format.
# Copyright (c) 2011-2019 Michael Buesch <m@bues.ch>
# Licensed under the GNU/GPL version 2 or later.`

Modules
`` |  |
errno |  |  |

Classes
`` |  | builtins.Exception(builtins.BaseException) FileObjError builtins.object FileObj FileObjCollection
class FileObj(builtins.object)
`` | `FileObj(name, data)`
| Methods defined here: __init__(self, name, data) `Construct FileObj(). name: The object name. Must be bytes-like. data: The object payload. Must be bytes-like.` getData(self) getName(self) getRaw(self) Class methods defined here: parseRaw(raw) from builtins.type Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class FileObjCollection(builtins.object)
`` | `FileObjCollection(*objects)`
| Methods defined here: __init__(self, *objects) `Initialize self. See help(type(self)) for accurate signature.` get(self, name) getOne(self, name, errorMsg=None, default=None) getRaw(self) writeFile(self, filepath) Class methods defined here: parseFile(filepath) from builtins.type parseRaw(raw) from builtins.type Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)`
class FileObjError(builtins.Exception)
`` |  | Method resolution order: FileObjError builtins.Exception builtins.BaseException builtins.object Data descriptors defined here: __weakref__ `list of weak references to the object (if defined)` Methods inherited from builtins.Exception: __init__(self, /, *args, **kwargs) `Initialize self. See help(type(self)) for accurate signature.` Static methods inherited from builtins.Exception: __new__(*args, **kwargs) from builtins.type `Create and return a new object. See help(type) for accurate signature.` Methods inherited from builtins.BaseException: __delattr__(self, name, /) `Implement delattr(self, name).` __getattribute__(self, name, /) `Return getattr(self, name).` __reduce__(...) `Helper for pickle.` __repr__(self, /) `Return repr(self).` __setattr__(self, name, value, /) `Implement setattr(self, name, value).` __setstate__(...) __str__(self, /) `Return str(self).` with_traceback(...) `Exception.with_traceback(tb) -- set self.__traceback__ to tb and return self.` Data descriptors inherited from builtins.BaseException: __cause__ `exception cause` __context__ `exception context` __dict__ __suppress_context__ __traceback__ args

Data
`` |  | __all__ = ['FileObjError', 'FileObj', 'FileObjCollection']